@@ -27,6 +27,9 @@
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
 
 #include <libxfce4util/libxfce4util.h>
 
@@ -104,12 +107,13 @@ terminal_option_show_hide_cmp (const gchar         *long_name,
                                TerminalVisibility  *return_visibility)
 {
   gchar *arg = argv[*argv_offset];
+  const size_t pref_len = strlen ("--show-");
 
   terminal_return_val_if_fail (long_name != NULL, FALSE);
   terminal_return_val_if_fail (return_visibility != NULL, FALSE);
 
-  if ((strncmp (arg, "--show-", 7) == 0 || strncmp (arg, "--hide-", 7) == 0)
-      && strcmp (arg + 7, long_name) == 0)
+  if ((strncmp (arg, "--show-", pref_len) == 0 || strncmp (arg, "--hide-", pref_len) == 0)
+      && strcmp (arg + pref_len, long_name) == 0)
     {
       if (*(arg + 2) == 's')
         *return_visibility = TERMINAL_VISIBILITY_SHOW;
@@ -192,6 +196,7 @@ terminal_window_attr_parse (gint              argc,
   GSList             *tp, *wp;
   GSList             *attrs;
   gint                n;
+  gchar              *end_ptr = NULL;
   TerminalVisibility  visible;
 
   win_attr = terminal_window_attr_new ();
@@ -444,6 +449,40 @@ terminal_window_attr_parse (gint              argc,
           tab_attr = win_attr->tabs->data;
           attrs = g_slist_append (attrs, win_attr);
         }
+      else if (terminal_option_cmp ("font", 0, argc, argv, &n, &s))
+        {
+          if (G_UNLIKELY (s == NULL))
+            {
+              g_set_error (error, G_SHELL_ERROR, G_SHELL_ERROR_FAILED,
+                           _("Option \"--font\" requires specifying "
+                             "the font name as its parameter"));
+              goto failed;
+            }
+          else
+            {
+              g_free (win_attr->font);
+              win_attr->font = g_strdup (s);
+              continue;
+            }
+        }
+      else if (terminal_option_cmp ("zoom", 0, argc, argv, &n, &s))
+        {
+          if (G_UNLIKELY (s == NULL) ||
+              strtol (s, &end_ptr, 0) < TERMINAL_ZOOM_LEVEL_MINIMUM ||
+              strtol (s, &end_ptr, 0) > TERMINAL_ZOOM_LEVEL_MAXIMUM)
+            {
+              g_set_error (error, G_SHELL_ERROR, G_SHELL_ERROR_FAILED,
+                           _("Option \"--zoom\" requires specifying "
+                             "the zoom (%d .. %d) as its parameter"),
+                           TERMINAL_ZOOM_LEVEL_MINIMUM, TERMINAL_ZOOM_LEVEL_MAXIMUM);
+              goto failed;
+            }
+          else
+            {
+              win_attr->zoom = strtol (s, &end_ptr, 0);
+              continue;
+            }
+        }
       else if (terminal_option_cmp ("disable-server", 0, argc, argv, &n, NULL)
                || terminal_option_cmp ("sync", 0, argc, argv, &n, NULL)
                || terminal_option_cmp ("g-fatal-warnings", 0, argc, argv, &n, NULL))
@@ -513,6 +552,7 @@ terminal_window_attr_new (void)
   win_attr->menubar = TERMINAL_VISIBILITY_DEFAULT;
   win_attr->borders = TERMINAL_VISIBILITY_DEFAULT;
   win_attr->toolbar = TERMINAL_VISIBILITY_DEFAULT;
+  win_attr->zoom = TERMINAL_ZOOM_LEVEL_DEFAULT;
 
   tab_attr = g_slice_new0 (TerminalTabAttr);
   win_attr->tabs = g_slist_prepend (NULL, tab_attr);
@@ -539,5 +579,6 @@ terminal_window_attr_free (TerminalWindowAttr *attr)
   g_free (attr->display);
   g_free (attr->role);
   g_free (attr->icon);
+  g_free (attr->font);
   g_slice_free (TerminalWindowAttr, attr);
 }
