@@ -17,10 +17,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __TERMINAL_SCREEN_H__
-#define __TERMINAL_SCREEN_H__
+#ifndef TERMINAL_SCREEN_H
+#define TERMINAL_SCREEN_H
 
 #include <gtk/gtk.h>
+#include <terminal/terminal-private.h>
 
 G_BEGIN_DECLS
 
@@ -40,6 +41,7 @@ void         terminal_screen_launch_child                 (TerminalScreen *scree
 
 void         terminal_screen_set_custom_command           (TerminalScreen *screen,
                                                            gchar         **command);
+const gchar *terminal_screen_get_custom_title             (TerminalScreen *screen);
 void         terminal_screen_set_custom_title             (TerminalScreen *screen,
                                                            const gchar    *title);
 
@@ -109,6 +111,13 @@ void         terminal_screen_search_find_previous         (TerminalScreen *scree
 
 void         terminal_screen_update_font                  (TerminalScreen *screen);
 
+void         terminal_screen_set_input_enabled            (TerminalScreen *screen,
+                                                           gboolean        enabled);
+
+void         terminal_screen_save_contents                (TerminalScreen *screen,
+                                                           GOutputStream  *stream,
+                                                           GError         *error);
+
 G_END_DECLS
 
-#endif /* !__TERMINAL_SCREEN_H__ */
+#endif /* !TERMINAL_SCREEN_H */
