@@ -36,23 +36,11 @@
 #include <terminal/terminal-preferences.h>
 #include <terminal/terminal-widget.h>
 #include <terminal/terminal-private.h>
+#include <terminal/terminal-regex.h>
 
 
 
 #define MAILTO          "mailto:"
-#define USERCHARS       "-[:alnum:]\\Q_.+\\E"
-#define USERCHARS_CLASS "[" USERCHARS "]"
-#define PASSCHARS_CLASS "[-[:alnum:]\\Q,?;.:/!%$^*&~\"#'\\E]"
-#define HOSTCHARS_CLASS "[-[:alnum:]]"
-#define HOSTNAME        HOSTCHARS_CLASS "+(?:\\." HOSTCHARS_CLASS "+)*"
-#define IPV6ADDRESS     "\\[(?:[[:xdigit:]]{0,4}:){2,7}[[:xdigit:]]{0,4}\\]"
-#define HOST            "(?:" HOSTNAME "|" IPV6ADDRESS ")"
-#define PORT            "(?:\\:[[:digit:]]{1,5})?"
-#define PATHCHARS_CLASS "[-[:alnum:]\\Q_$.+!*,;@&=?/:~#'%\\E]"
-#define PATHTERM_CLASS  "[[:alnum:]\\Q_$+*@&=/~#%\\E]"
-#define SCHEME          "(?:news:|telnet:|nntp:|file:\\/|https?:|ftps?:|sftp:|webcal:|magnet:)"
-#define USERPASS        USERCHARS_CLASS "+(?:" PASSCHARS_CLASS "+)?"
-#define URLPATH         "(?:(?:\\(" PATHCHARS_CLASS "*\\)|" PATHCHARS_CLASS ")*(?:\\(" PATHCHARS_CLASS "*\\)|" PATHTERM_CLASS "))?"
 
 
 
@@ -78,45 +66,42 @@ typedef struct
 
 static const TerminalRegexPattern regex_patterns[] =
 {
-  { SCHEME "//(?:" USERPASS "\\@)?" HOST PORT URLPATH, PATTERN_TYPE_FULL_HTTP },
-  { "(?:www[[:digit:]]{0,3}|ftp)" HOSTCHARS_CLASS "*\\." HOST PORT URLPATH, PATTERN_TYPE_HTTP },
-  { "(?:" MAILTO ")?" USERCHARS_CLASS "[" USERCHARS ".]*\\@" HOSTCHARS_CLASS "+\\." HOST, PATTERN_TYPE_EMAIL },
-  { "news:[[:alnum:]\\Q^_{|}~!\"#$%&'()*+,./;:=?`\\E]+", PATTERN_TYPE_FULL_HTTP },
-  { "magnet:[-[:alnum:]\\Q^_{|}~!\"#$%&'()*+,./;:=?`\\E]+", PATTERN_TYPE_FULL_HTTP }
+  { REGEX_URL_AS_IS, PATTERN_TYPE_FULL_HTTP },
+  { REGEX_URL_HTTP,  PATTERN_TYPE_HTTP },
+  { REGEX_URL_FILE,  PATTERN_TYPE_FULL_HTTP },
+  { REGEX_EMAIL,     PATTERN_TYPE_EMAIL },
+  { REGEX_NEWS_MAN,  PATTERN_TYPE_FULL_HTTP },
 };
 
 
 
-static void     terminal_widget_finalize              (GObject              *object);
-static gboolean terminal_widget_button_press_event    (GtkWidget            *widget,
-                                                       GdkEventButton       *event);
-static void     terminal_widget_drag_data_received    (GtkWidget            *widget,
-                                                       GdkDragContext       *context,
-                                                       gint                  x,
-                                                       gint                  y,
-                                                       GtkSelectionData     *selection_data,
-                                                       guint                 info,
-                                                       guint                 time);
-static gboolean terminal_widget_key_press_event       (GtkWidget            *widget,
-                                                       GdkEventKey          *event);
-static void     terminal_widget_open_uri              (TerminalWidget       *widget,
-                                                       const gchar          *link,
-                                                       gint                  tag);
-static void     terminal_widget_update_highlight_urls (TerminalWidget       *widget);
+static void     terminal_widget_finalize              (GObject          *object);
+static gboolean terminal_widget_button_press_event    (GtkWidget        *widget,
+                                                       GdkEventButton   *event);
+static void     terminal_widget_drag_data_received    (GtkWidget        *widget,
+                                                       GdkDragContext   *context,
+                                                       gint              x,
+                                                       gint              y,
+                                                       GtkSelectionData *selection_data,
+                                                       guint             info,
+                                                       guint             time);
+static gboolean terminal_widget_key_press_event       (GtkWidget        *widget,
+                                                       GdkEventKey      *event);
+static void     terminal_widget_open_uri              (TerminalWidget   *widget,
+                                                       const gchar      *link,
+                                                       gint              tag);
+static void     terminal_widget_update_highlight_urls (TerminalWidget   *widget);
 
 
 
 struct _TerminalWidgetClass
 {
-  VteTerminalClass __parent__;
-
-  /* signals */
-  GtkWidget*  (*get_context_menu) (TerminalWidget        *widget);
+  VteTerminalClass parent_class;
 };
 
 struct _TerminalWidget
 {
-  VteTerminal __parent__;
+  VteTerminal          parent_instance;
 
   /*< private >*/
   TerminalPreferences *preferences;
@@ -758,9 +743,15 @@ terminal_widget_update_highlight_urls (TerminalWidget *widget)
 
           /* build the regex */
           error = NULL;
+#if VTE_CHECK_VERSION (0, 45, 90)
+          regex = vte_regex_new_for_match (pattern->pattern, -1,
+                                           PCRE2_CASELESS | PCRE2_UTF | PCRE2_NO_UTF_CHECK | PCRE2_MULTILINE,
+                                           &error);
+#else
           regex = g_regex_new (pattern->pattern,
-                               G_REGEX_CASELESS | G_REGEX_OPTIMIZE,
+                               G_REGEX_CASELESS | G_REGEX_OPTIMIZE | G_REGEX_MULTILINE,
                                0, &error);
+#endif
           if (G_UNLIKELY (error != NULL))
             {
               g_critical ("Failed to parse regular expression pattern %d: %s",
