@@ -61,34 +61,34 @@ enum
 
 
 
-static void            terminal_window_dropdown_finalize                      (GObject                *object);
-static void            terminal_window_dropdown_set_property                  (GObject                *object,
-                                                                               guint                   prop_id,
-                                                                               const GValue           *value,
-                                                                               GParamSpec             *pspec);
-static gboolean        terminal_window_dropdown_focus_in_event                (GtkWidget              *widget,
-                                                                               GdkEventFocus          *event);
-static gboolean        terminal_window_dropdown_focus_out_event               (GtkWidget              *widget,
-                                                                               GdkEventFocus          *event);
-static gboolean        terminal_window_dropdown_status_icon_press_event       (GtkStatusIcon          *status_icon,
-                                                                               GdkEventButton         *event,
-                                                                               TerminalWindowDropdown *dropdown);
-static void            terminal_window_dropdown_status_icon_popup_menu        (GtkStatusIcon          *status_icon,
-                                                                               guint                   button,
-                                                                               guint32                 timestamp,
-                                                                               TerminalWindowDropdown *dropdown);
-static void            terminal_window_dropdown_hide                          (TerminalWindowDropdown *dropdown);
-static void            terminal_window_dropdown_show                          (TerminalWindowDropdown *dropdown,
-                                                                               guint32                 timestamp);
-static void            terminal_window_dropdown_toggle_real                   (TerminalWindowDropdown *dropdown,
-                                                                               guint32                 timestamp,
-                                                                               gboolean                force_show);
-static void            terminal_window_dropdown_update_geometry               (TerminalWindowDropdown *dropdown);
+static void     terminal_window_dropdown_finalize                (GObject                *object);
+static void     terminal_window_dropdown_set_property            (GObject                *object,
+                                                                  guint                   prop_id,
+                                                                  const GValue           *value,
+                                                                  GParamSpec             *pspec);
+static gboolean terminal_window_dropdown_focus_in_event          (GtkWidget              *widget,
+                                                                  GdkEventFocus          *event);
+static gboolean terminal_window_dropdown_focus_out_event         (GtkWidget              *widget,
+                                                                  GdkEventFocus          *event);
+static gboolean terminal_window_dropdown_status_icon_press_event (GtkStatusIcon          *status_icon,
+                                                                  GdkEventButton         *event,
+                                                                  TerminalWindowDropdown *dropdown);
+static void     terminal_window_dropdown_status_icon_popup_menu  (GtkStatusIcon          *status_icon,
+                                                                  guint                   button,
+                                                                  guint32                 timestamp,
+                                                                  TerminalWindowDropdown *dropdown);
+static void     terminal_window_dropdown_hide                    (TerminalWindowDropdown *dropdown);
+static void     terminal_window_dropdown_show                    (TerminalWindowDropdown *dropdown,
+                                                                  guint32                 timestamp);
+static void     terminal_window_dropdown_toggle_real             (TerminalWindowDropdown *dropdown,
+                                                                  guint32                 timestamp,
+                                                                  gboolean                force_show);
+static void     terminal_window_dropdown_update_geometry         (TerminalWindowDropdown *dropdown);
 
 
 struct _TerminalWindowDropdownClass
 {
-  TerminalWindowClass __parent__;
+  TerminalWindowClass parent_class;
 };
 
 typedef enum
@@ -100,10 +100,7 @@ typedef enum
 
 struct _TerminalWindowDropdown
 {
-  TerminalWindow __parent__;
-
-  /* viewport for animation */
-  GtkWidget           *viewport;
+  TerminalWindow       parent_instance;
 
   /* timeout for animation */
   guint                animation_timeout_id;
@@ -221,7 +218,6 @@ terminal_window_dropdown_init (TerminalWindowDropdown *dropdown)
   const gchar    *name;
   gboolean        keep_open;
   gboolean        show_borders;
-  GtkWidget      *child;
 
   dropdown->rel_width = 0.80;
   dropdown->rel_height = 0.50;
@@ -231,16 +227,6 @@ terminal_window_dropdown_init (TerminalWindowDropdown *dropdown)
   /* shared setting to disable some functionality in TerminalWindow */
   window->drop_down = TRUE;
 
-  /* move the window content into a viewport for animation */
-  dropdown->viewport = gtk_viewport_new (NULL, NULL);
-  gtk_viewport_set_shadow_type (GTK_VIEWPORT (dropdown->viewport), GTK_SHADOW_NONE);
-  child = gtk_bin_get_child (GTK_BIN (dropdown));
-  g_object_ref (G_OBJECT (child));
-  gtk_container_remove (GTK_CONTAINER (dropdown), child);
-  gtk_container_add (GTK_CONTAINER (dropdown), dropdown->viewport);
-  gtk_container_add (GTK_CONTAINER (dropdown->viewport), child);
-  g_object_unref (G_OBJECT (child));
-
   /* default window settings */
   gtk_window_set_decorated (GTK_WINDOW (dropdown), FALSE);
   gtk_window_set_gravity (GTK_WINDOW (dropdown), GDK_GRAVITY_STATIC);
@@ -562,28 +548,36 @@ terminal_window_dropdown_animate_down (gpointer data)
 {
   TerminalWindowDropdown *dropdown = TERMINAL_WINDOW_DROPDOWN (data);
   TerminalWindow         *window = TERMINAL_WINDOW (data);
-  GtkRequisition          req1, req2;
-  gint                    step_size;
-  gint                    viewport_h;
+  GtkRequisition          req1;
+  GdkRectangle            rect;
+  gint                    step_size, vbox_h;
+
+  /* get window size */
+  gdk_screen_get_monitor_geometry (dropdown->screen, dropdown->monitor_num, &rect);
+  if (!gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (window->action_fullscreen)))
+    {
+      /* calculate width/height if not fullscreen */
+      rect.width *= dropdown->rel_width;
+      rect.height *= dropdown->rel_height;
+    }
 
   /* decrease each interval */
-  gtk_widget_get_preferred_size (window->vbox, &req1, NULL);
-  step_size = req1.height * ANIMATION_FPS / dropdown->animation_time;
+  step_size = rect.height * ANIMATION_FPS / dropdown->animation_time;
   if (step_size < 1)
     step_size = 1;
 
-  /* new viewport size */
-  gtk_widget_get_preferred_size (dropdown->viewport, &req2, NULL);
-  viewport_h = req2.height + step_size;
-  if (viewport_h > req1.height)
-    viewport_h = req1.height;
+  /* new vbox size */
+  gtk_widget_get_preferred_size (window->vbox, &req1, NULL);
+  vbox_h = req1.height + step_size;
+  if (vbox_h > rect.height)
+    vbox_h = rect.height;
 
   /* resize */
-  gtk_widget_set_size_request (dropdown->viewport, req2.width, viewport_h);
-  gtk_window_resize (GTK_WINDOW (dropdown), req2.width, viewport_h);
+  gtk_widget_set_size_request (window->vbox, req1.width, vbox_h);
+  gtk_window_resize (GTK_WINDOW (window), req1.width, vbox_h);
 
   /* continue the animation */
-  if (viewport_h < req1.height)
+  if (vbox_h < rect.height)
     return TRUE;
 
   /* restore the fullscreen state */
@@ -601,49 +595,45 @@ terminal_window_dropdown_animate_up (gpointer data)
 {
   TerminalWindowDropdown *dropdown = TERMINAL_WINDOW_DROPDOWN (data);
   TerminalWindow         *window = TERMINAL_WINDOW (data);
-  GtkRequisition          req1, req2;
-  gint                    step_size, viewport_h, min_size;
+  GtkRequisition          req1;
   GdkRectangle            rect;
+  gint                    step_size, vbox_h, min_size;
 
   /* get window size */
-  if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (window->action_fullscreen)))
+  gdk_screen_get_monitor_geometry (dropdown->screen, dropdown->monitor_num, &rect);
+  if (!gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (window->action_fullscreen)))
     {
-      /* use the monitor size for the animation */
-      gdk_screen_get_monitor_geometry (dropdown->screen, dropdown->monitor_num, &rect);
-      req1.width = rect.width;
-      req1.height = rect.height;
-    }
-  else
-    {
-      gtk_widget_get_preferred_size (window->vbox, &req1, NULL);
+      /* calculate width/height if not fullscreen */
+      rect.width *= dropdown->rel_width;
+      rect.height *= dropdown->rel_height;
     }
 
   /* decrease each interval */
-  step_size = req1.height * ANIMATION_FPS / dropdown->animation_time;
+  step_size = rect.height * ANIMATION_FPS / dropdown->animation_time;
   if (step_size < 1)
     step_size = 1;
 
-  /* new viewport size */
-  gtk_widget_get_preferred_size (dropdown->viewport, &req2, NULL);
-  viewport_h = req2.height - step_size;
+  /* new vbox size */
+  gtk_widget_get_preferred_size (window->vbox, &req1, NULL);
+  vbox_h = req1.height - step_size;
 
   /* sizes of the widgets that cannot be shrunk */
-  gtk_widget_get_preferred_size (window->notebook, &req2, NULL);
-  min_size = req2.height;
+  gtk_widget_get_preferred_size (window->notebook, &req1, NULL);
+  min_size = req1.height;
   if (window->menubar != NULL
       && gtk_widget_get_visible (window->menubar))
     {
-      gtk_widget_get_preferred_size (window->menubar, &req2, NULL);
-      min_size += req2.height;
+      gtk_widget_get_preferred_size (window->menubar, &req1, NULL);
+      min_size += req1.height;
     }
   if (window->toolbar != NULL
       && gtk_widget_get_visible (window->toolbar))
     {
-      gtk_widget_get_preferred_size (window->toolbar, &req2, NULL);
-      min_size += req2.height;
+      gtk_widget_get_preferred_size (window->toolbar, &req1, NULL);
+      min_size += req1.height;
     }
 
-  if (viewport_h < min_size)
+  if (vbox_h < min_size)
     {
       /* animation complete */
       gtk_widget_hide (GTK_WIDGET (dropdown));
@@ -651,9 +641,9 @@ terminal_window_dropdown_animate_up (gpointer data)
     }
 
   /* resize window */
-  gtk_widget_set_size_request (dropdown->viewport, req1.width, viewport_h);
-  gtk_widget_set_size_request (window->vbox, req1.width, viewport_h);
-  gtk_window_resize (GTK_WINDOW (dropdown), req1.width, viewport_h);
+  gtk_widget_set_size_request (window->vbox, rect.width, vbox_h);
+  gtk_window_resize (GTK_WINDOW (window), rect.width, vbox_h);
+
   return TRUE;
 }
 
@@ -698,11 +688,10 @@ terminal_window_dropdown_show (TerminalWindowDropdown *dropdown,
   gint               w, h;
   GdkRectangle       monitor_geo;
   gint               x_dest, y_dest;
-  glong              char_width, char_height;
   GtkRequisition     req1;
   gboolean           move_to_active;
   gboolean           visible;
-  gint               viewport_h;
+  gint               vbox_h;
   TerminalDirection  old_animation_dir = ANIMATION_DIR_NONE;
 
   visible = gtk_widget_get_visible (GTK_WIDGET (dropdown));
@@ -729,9 +718,6 @@ terminal_window_dropdown_show (TerminalWindowDropdown *dropdown,
   /* move window to correct screen */
   gtk_window_set_screen (GTK_WINDOW (dropdown), dropdown->screen);
 
-  /* get terminal size */
-  terminal_screen_get_geometry (window->active, &char_width, &char_height, NULL, NULL);
-
   /* correct padding with notebook size */
   if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (window->action_fullscreen)))
     {
@@ -750,48 +736,44 @@ terminal_window_dropdown_show (TerminalWindowDropdown *dropdown,
       h = monitor_geo.height * dropdown->rel_height;
     }
 
-  /* viewport size if not animated */
-  viewport_h = h;
+  /* vbox size if not animated */
+  vbox_h = h;
 
-  /* viewport start height for animation */
+  /* vbox start height for animation */
   if (dropdown->animation_time > 0)
     {
       if (!visible)
         {
           /* start animation collapsed */
-          viewport_h = 0;
+          vbox_h = 0;
         }
       else if (old_animation_dir == ANIMATION_DIR_UP)
         {
           /* pick up where we aborted */
-          gtk_widget_get_preferred_size (dropdown->viewport, &req1, NULL);
-          viewport_h = req1.height;
+          gtk_widget_get_preferred_size (window->vbox, &req1, NULL);
+          vbox_h = req1.height;
         }
     }
 
-  /* resize the widgets */
-  gtk_widget_set_size_request (window->vbox, w, h);
-  gtk_widget_set_size_request (dropdown->viewport, w, viewport_h);
+  /* resize */
+  gtk_widget_set_size_request (window->vbox, w, vbox_h);
 
   /* calc position */
   x_dest = monitor_geo.x + (monitor_geo.width - w) * dropdown->rel_position;
   y_dest = monitor_geo.y;
 
-  /* move */
-  gtk_window_move (GTK_WINDOW (dropdown), x_dest, y_dest);
-
   /* show window */
   if (!visible)
-    {
-      gtk_widget_show_all (GTK_WIDGET (dropdown));
-      gtk_window_present_with_time (GTK_WINDOW (dropdown), timestamp);
-    }
+    gtk_window_present_with_time (GTK_WINDOW (dropdown), timestamp);
+
+  /* move */
+  gtk_window_move (GTK_WINDOW (dropdown), x_dest, y_dest);
 
   /* force focus to the window */
   terminal_util_activate_window (GTK_WINDOW (dropdown));
 
   if (dropdown->animation_time > 0
-      && viewport_h < h)
+      && vbox_h < h)
     {
       dropdown->animation_dir = ANIMATION_DIR_DOWN;
       dropdown->animation_timeout_id =
