@@ -1656,10 +1656,16 @@ static void
 terminal_window_action_readonly (GtkToggleAction *action,
                                  TerminalWindow  *window)
 {
+  gboolean input_enabled;
+
   terminal_return_if_fail (window->active != NULL);
 
-  terminal_screen_set_input_enabled (window->active,
-                                     !gtk_toggle_action_get_active (action));
+  input_enabled = !gtk_toggle_action_get_active (action);
+  gtk_action_set_sensitive (gtk_action_group_get_action (window->action_group, "reset"),
+                            input_enabled);
+  gtk_action_set_sensitive (gtk_action_group_get_action (window->action_group, "reset-and-clear"),
+                            input_enabled);
+  terminal_screen_set_input_enabled (window->active, input_enabled);
 }
 
 
@@ -2078,6 +2084,7 @@ terminal_window_zoom_update_screens (TerminalWindow *window)
 {
   gint            npages, n;
   TerminalScreen *screen;
+  GtkAction      *action;
 
   terminal_return_if_fail (GTK_IS_NOTEBOOK (window->notebook));
 
@@ -2088,6 +2095,19 @@ terminal_window_zoom_update_screens (TerminalWindow *window)
       screen = TERMINAL_SCREEN (gtk_notebook_get_nth_page (GTK_NOTEBOOK (window->notebook), n));
       terminal_screen_update_font (screen);
     }
+
+  /* update zoom actions */
+  action = gtk_action_group_get_action (window->action_group, "zoom-in");
+  if (window->zoom == TERMINAL_ZOOM_LEVEL_MAXIMUM)
+    gtk_action_set_sensitive (action, FALSE);
+  else if (!gtk_action_is_sensitive (action))
+    gtk_action_set_sensitive (action, TRUE);
+
+  action = gtk_action_group_get_action (window->action_group, "zoom-out");
+  if (window->zoom == TERMINAL_ZOOM_LEVEL_MINIMUM)
+      gtk_action_set_sensitive (action, FALSE);
+    else if (!gtk_action_is_sensitive (action))
+      gtk_action_set_sensitive (action, TRUE);
 }
 
 
